==> funki-0.0.73.tar.gz: funki-0.0.73/funki/report.py <==
from time import time

import funki.text_colours as tc

φ = lambda x: ('\n' if '\n' in x else '') + f'{x}'

def _duration_bar(duration_ms):
  max_width = 32
  width = min(round(duration_ms / 0.03125), max_width)
  return width*'█' + (max_width-width)*' '

def _duration(t_0):
  T_ms = (time()-t_0)*1000
  
  style = tc.bright_red
  if T_ms < 0.25000: style = tc.bright_magenta
  if T_ms < 0.12500: style = tc.bright_blue
  if T_ms < 0.06250: style = tc.bright_cyan
  if T_ms < 0.03125: style = tc.bright_green

  return style(f'{_duration_bar} {T_ms:.3f} [ms]')

def fail(name, xyz, mode, time_started):
  print('\n'.join([
    f"\r{tc.danger('FAIL')} | {_duration(time_started)} | {name}()   ",
    f"{tc.danger('mode:')} {mode}",
    f"{tc.primary('Input       x_args:   ')} {φ(str(xyz['x_args']))}",
    f"{tc.primary('Expectation y_return: ')} {φ(str(xyz['y_return']))}",
    f"{tc.primary('Observation z_return: ')} {φ(str(xyz['z_return']))}",
    f"{tc.secondary('Input       x_stdi: ')} {φ(str(xyz['x_stdi']))}",
    f"{tc.secondary('Expectation y_stdo: ')} {φ(str(xyz['y_stdo']))}",
    f"{tc.secondary('Observation z_stdo: ')} {φ(str(xyz['z_stdo']))}",
  ]))
  return False

def property_failure(name, mode, time_started):
  print('\n'.join([
    f"\r{tc.danger('FAIL')} | {_duration(time_started)} | {name}()   ",
    f"{tc.danger('mode:')} {mode}",
  ]))
  return False

def success(name, time_started):
  print(f"\r{tc.success('PASS')} | {_duration(time_started)} | {name}()")
  return True

==> funki-0.0.82.tar.gz: funki-0.0.82/funki/report.py <==
from time import time
from math import log
from math import ceil

import funki.text_colours as tc

φ_a = lambda x: ('\n' if '\n' in x else '') + f'{x}'

def φ(x):
  max_length = 24*450

  result = φ_a(x)
  if len(result) > max_length:
    result = result[:max_length] + '...'
  
  return result

def _duration_bar(duration_ms):
  max_width = 64
  # width = min(round(duration_ms / 0.03125), max_width)
  width = min(max(0, ceil(log(1000*duration_ms, 2))), max_width)
  return width*'█' + (max_width-width)*' '

def _duration(t_0):
  T_ms = (time()-t_0)*1000

  with open('max_duration.val', 'w')
  
  style = tc.bright_red
  if T_ms < 0.25000: style = tc.bright_magenta
  if T_ms < 0.12500: style = tc.bright_blue
  if T_ms < 0.06250: style = tc.bright_cyan
  if T_ms < 0.03125: style = tc.bright_green

  return style(f'{_duration_bar(T_ms)} {T_ms:7.3f} [ms]')

def fail(name, xyz, mode, time_started):
  print('\n'.join([
    f"\r{tc.danger('FAIL')} | {_duration(time_started)} | {name}()   ",
    f"{tc.danger('mode:')} {mode}",
    f"{tc.primary('Input       x_args:   ')} {φ(str(xyz['x_args']))}",
    f"{tc.primary('Expectation y_return: ')} {φ(str(xyz['y_return']))}",
    f"{tc.primary('Observation z_return: ')} {φ(str(xyz['z_return']))}",
    f"{tc.secondary('Input       x_stdi: ')} {φ(str(xyz['x_stdi']))}",
    f"{tc.secondary('Expectation y_stdo: ')} {φ(str(xyz['y_stdo']))}",
    f"{tc.secondary('Observation z_stdo: ')} {φ(str(xyz['z_stdo']))}",
  ]))
  return False

def property_failure(name, mode, time_started):
  print('\n'.join([
    f"\r{tc.danger('FAIL')} | {_duration(time_started)} | {name}()   ",
    f"{tc.danger('mode:')} {mode}",
  ]))
  return False

def success(name, time_started):
  print(f"\r{tc.success('PASS')} | {_duration(time_started)} | {name}()")
  return True
